@@ -1,7 +1,12 @@
 """Ready to use and customizable Authentications and Oauth2 management for FastAPI"""
 
-__version__ = "0.0.6"
+__version__ = "0.0.9"
 
+__license__ = "MIT"
+
+__author__ = "Yezz123"
+
+__author_email__ = "yasserth19@gmail.com"
 
 from AuthX.main import Authentication, AuthX, User
 
