@@ -10,9 +10,24 @@ class LevelFilter:
     """
 
     def __init__(self, level):
+        """
+        Initialize the instance.
+
+        Args:
+            level (int): The level to filter on.
+        """
         self._level = level
 
     def filter(self, log_record):
+        """
+        Filter the log record.
+
+        Args:
+            log_record (logging.LogRecord): The log record to filter.
+
+        Returns:
+            bool: True if the record should be logged, False otherwise.
+        """
         return log_record.levelno == self._level
 
 
@@ -29,6 +44,9 @@ if DEBUG:
         "logs/info.log", when="midnight", backupCount=7
     )
 else:
+    """
+        Log to file
+    """
     log_info = logging.StreamHandler()
 
 log_info.addFilter(LevelFilter(logging.INFO))  # type: ignore
