@@ -4,6 +4,12 @@ class User:
     """
 
     def __init__(self, data=None):
+        """
+        Initialize the user object
+
+        Args:
+            data (dict): A dictionary containing the user's data
+        """
         self.data = data
         if data is None:
             self.is_authenticated = False
@@ -18,5 +24,14 @@ class User:
 
     @classmethod
     async def create(cls, token: str, backend):
+        """
+        Create a user object from a token
+
+        Args:
+            token (str): The token to create the user object from
+            backend (AuthX): The backend to use to create the user object
+        Returns:
+            User: The user object
+        """
         data = await backend.decode_token(token)
         return cls(data)
